@@ -3,4 +3,5 @@ This classes implement the same API as the v0.4 SDK, but are
 compatible with the new Apibara Stream protocol.
 """
 
-from .runner import IndexerRunner, IndexerRunnerConfiguration, Info
+from .handler import Info, MessageHandler, UserContext
+from .runner import IndexerRunner, IndexerRunnerConfiguration
